@@ -1,8 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 7                                                        |
-   +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2018 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -22,7 +20,7 @@
 #endif
 
 #include "php.h"
-#if HAVE_LIBXML && HAVE_DOM
+#if defined(HAVE_LIBXML) && defined(HAVE_DOM)
 #include "php_dom.h"
 
 #define PHP_DOM_XPATH_QUERY 0
@@ -32,43 +30,7 @@
 * class DOMXPath
 */
 
-#if defined(LIBXML_XPATH_ENABLED)
-
-/* {{{ arginfo */
-ZEND_BEGIN_ARG_INFO_EX(arginfo_dom_xpath_construct, 0, 0, 1)
-	ZEND_ARG_OBJ_INFO(0, doc, DOMDocument, 0)
-ZEND_END_ARG_INFO();
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_dom_xpath_register_ns, 0, 0, 2)
-	ZEND_ARG_INFO(0, prefix)
-	ZEND_ARG_INFO(0, uri)
-ZEND_END_ARG_INFO();
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_dom_xpath_query, 0, 0, 1)
-	ZEND_ARG_INFO(0, expr)
-	ZEND_ARG_OBJ_INFO(0, context, DOMNode, 1)
-	ZEND_ARG_INFO(0, registerNodeNS)
-ZEND_END_ARG_INFO();
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_dom_xpath_evaluate, 0, 0, 1)
-	ZEND_ARG_INFO(0, expr)
-	ZEND_ARG_OBJ_INFO(0, context, DOMNode, 1)
-	ZEND_ARG_INFO(0, registerNodeNS)
-ZEND_END_ARG_INFO();
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_dom_xpath_register_php_functions, 0, 0, 0)
-ZEND_END_ARG_INFO();
-/* }}} */
-
-const zend_function_entry php_dom_xpath_class_functions[] = {
-	PHP_ME(domxpath, __construct, arginfo_dom_xpath_construct, ZEND_ACC_PUBLIC)
-	PHP_FALIAS(registerNamespace, dom_xpath_register_ns, arginfo_dom_xpath_register_ns)
-	PHP_FALIAS(query, dom_xpath_query, arginfo_dom_xpath_query)
-	PHP_FALIAS(evaluate, dom_xpath_evaluate, arginfo_dom_xpath_evaluate)
-	PHP_FALIAS(registerPhpFunctions, dom_xpath_register_php_functions, arginfo_dom_xpath_register_php_functions)
-	PHP_FE_END
-};
-
+#ifdef LIBXML_XPATH_ENABLED
 
 static void dom_xpath_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs, int type) /* {{{ */
 {
@@ -174,29 +136,23 @@ static void dom_xpath_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs,
 
 	obj = valuePop(ctxt);
 	if (obj->stringval == NULL) {
-		php_error_docref(NULL, E_WARNING, "Handler name must be a string");
+		zend_type_error("Handler name must be a string");
 		xmlXPathFreeObject(obj);
-		if (fci.param_count > 0) {
-			for (i = 0; i < nargs - 1; i++) {
-				zval_ptr_dtor(&fci.params[i]);
-			}
-			efree(fci.params);
-		}
-		return;
+		goto cleanup;
 	}
 	ZVAL_STRING(&fci.function_name, (char *) obj->stringval);
 	xmlXPathFreeObject(obj);
 
 	fci.object = NULL;
+	fci.named_params = NULL;
 	fci.retval = &retval;
-	fci.no_separation = 0;
 
 	if (!zend_make_callable(&fci.function_name, &callable)) {
-		php_error_docref(NULL, E_WARNING, "Unable to call handler %s()", ZSTR_VAL(callable));
+		zend_throw_error(NULL, "Unable to call handler %s()", ZSTR_VAL(callable));
+		goto cleanup;
 	} else if (intern->registerPhpFunctions == 2 && zend_hash_exists(intern->registered_phpfunctions, callable) == 0) {
-		php_error_docref(NULL, E_WARNING, "Not allowed to call handler '%s()'.", ZSTR_VAL(callable));
-		/* Push an empty string, so that we at least have an xslt result... */
-		valuePush(ctxt, xmlXPathNewString((xmlChar *)""));
+		zend_throw_error(NULL, "Not allowed to call handler '%s()'.", ZSTR_VAL(callable));
+		goto cleanup;
 	} else {
 		result = zend_call_function(&fci, NULL);
 		if (result == SUCCESS && Z_TYPE(retval) != IS_UNDEF) {
@@ -214,8 +170,8 @@ static void dom_xpath_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs,
 			} else if (Z_TYPE(retval) == IS_FALSE || Z_TYPE(retval) == IS_TRUE) {
 				valuePush(ctxt, xmlXPathNewBoolean(Z_TYPE(retval) == IS_TRUE));
 			} else if (Z_TYPE(retval) == IS_OBJECT) {
-				php_error_docref(NULL, E_WARNING, "A PHP Object cannot be converted to a XPath-string");
-				valuePush(ctxt, xmlXPathNewString((xmlChar *)""));
+				zend_type_error("A PHP Object cannot be converted to a XPath-string");
+				return;
 			} else {
 				zend_string *str = zval_get_string(&retval);
 				valuePush(ctxt, xmlXPathNewString((xmlChar *) ZSTR_VAL(str)));
@@ -224,6 +180,7 @@ static void dom_xpath_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs,
 			zval_ptr_dtor(&retval);
 		}
 	}
+cleanup:
 	zend_string_release_ex(callable, 0);
 	zval_ptr_dtor_str(&fci.function_name);
 	if (fci.param_count > 0) {
@@ -247,17 +204,18 @@ static void dom_xpath_ext_function_object_php(xmlXPathParserContextPtr ctxt, int
 }
 /* }}} */
 
-/* {{{ proto DOMXPath::__construct(DOMDocument doc) U */
-PHP_METHOD(domxpath, __construct)
+/* {{{ */
+PHP_METHOD(DOMXPath, __construct)
 {
-	zval *id = getThis(), *doc;
+	zval *doc;
+	zend_bool register_node_ns = 1;
 	xmlDocPtr docp = NULL;
 	dom_object *docobj;
 	dom_xpath_object *intern;
 	xmlXPathContextPtr ctx, oldctx;
 
-	if (zend_parse_parameters_throw(ZEND_NUM_ARGS(), "O", &doc, dom_document_class_entry) == FAILURE) {
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "O|b", &doc, dom_document_class_entry, &register_node_ns) == FAILURE) {
+		RETURN_THROWS();
 	}
 
 	DOM_GET_OBJ(docp, doc, xmlDocPtr, docobj);
@@ -265,10 +223,10 @@ PHP_METHOD(domxpath, __construct)
 	ctx = xmlXPathNewContext(docp);
 	if (ctx == NULL) {
 		php_dom_throw_error(INVALID_STATE_ERR, 1);
-		RETURN_FALSE;
+		RETURN_THROWS();
 	}
 
-	intern = Z_XPATHOBJ_P(id);
+	intern = Z_XPATHOBJ_P(ZEND_THIS);
 	if (intern != NULL) {
 		oldctx = (xmlXPathContextPtr)intern->dom.ptr;
 		if (oldctx != NULL) {
@@ -286,6 +244,7 @@ PHP_METHOD(domxpath, __construct)
 		intern->dom.ptr = ctx;
 		ctx->userData = (void *)intern;
 		intern->dom.document = docobj->document;
+		intern->register_node_ns = register_node_ns;
 		php_libxml_increment_doc_ref((php_libxml_node_object *) &intern->dom, docp);
 	}
 }
@@ -306,8 +265,28 @@ int dom_xpath_document_read(dom_object *obj, zval *retval)
 }
 /* }}} */
 
-/* {{{ proto bool dom_xpath_register_ns(string prefix, string uri) */
-PHP_FUNCTION(dom_xpath_register_ns)
+/* {{{ registerNodeNamespaces bool*/
+static inline dom_xpath_object *php_xpath_obj_from_dom_obj(dom_object *obj) {
+	return (dom_xpath_object*)((char*)(obj) - XtOffsetOf(dom_xpath_object, dom));
+}
+
+int dom_xpath_register_node_ns_read(dom_object *obj, zval *retval)
+{
+	ZVAL_BOOL(retval, php_xpath_obj_from_dom_obj(obj)->register_node_ns);
+
+	return SUCCESS;
+}
+
+int dom_xpath_register_node_ns_write(dom_object *obj, zval *newval)
+{
+	php_xpath_obj_from_dom_obj(obj)->register_node_ns = zend_is_true(newval);
+
+	return SUCCESS;
+}
+/* }}} */
+
+/* {{{ */
+PHP_METHOD(DOMXPath, registerNamespace)
 {
 	zval *id;
 	xmlXPathContextPtr ctxp;
@@ -315,20 +294,21 @@ PHP_FUNCTION(dom_xpath_register_ns)
 	dom_xpath_object *intern;
 	unsigned char *prefix, *ns_uri;
 
-	if (zend_parse_method_parameters(ZEND_NUM_ARGS(), getThis(), "Oss", &id, dom_xpath_class_entry, &prefix, &prefix_len, &ns_uri, &ns_uri_len) == FAILURE) {
-		return;
+	id = ZEND_THIS;
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "ss", &prefix, &prefix_len, &ns_uri, &ns_uri_len) == FAILURE) {
+		RETURN_THROWS();
 	}
 
 	intern = Z_XPATHOBJ_P(id);
 
 	ctxp = (xmlXPathContextPtr) intern->dom.ptr;
 	if (ctxp == NULL) {
-		php_error_docref(NULL, E_WARNING, "Invalid XPath Context");
-		RETURN_FALSE;
+		zend_throw_error(NULL, "Invalid XPath Context");
+		RETURN_THROWS();
 	}
 
 	if (xmlXPathRegisterNs(ctxp, prefix, ns_uri) != 0) {
-		RETURN_FALSE
+		RETURN_FALSE;
 	}
 	RETURN_TRUE;
 }
@@ -355,18 +335,20 @@ static void php_xpath_eval(INTERNAL_FUNCTION_PARAMETERS, int type) /* {{{ */
 	char *expr;
 	xmlDoc *docp = NULL;
 	xmlNsPtr *ns = NULL;
-	zend_bool register_node_ns = 1;
-
-	if (zend_parse_method_parameters(ZEND_NUM_ARGS(), getThis(), "Os|O!b", &id, dom_xpath_class_entry, &expr, &expr_len, &context, dom_node_class_entry, &register_node_ns) == FAILURE) {
-		return;
-	}
+	zend_bool register_node_ns;
 
+	id = ZEND_THIS;
 	intern = Z_XPATHOBJ_P(id);
+	register_node_ns = intern->register_node_ns;
+
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|O!b", &expr, &expr_len, &context, dom_node_class_entry, &register_node_ns) == FAILURE) {
+		RETURN_THROWS();
+	}
 
 	ctxp = (xmlXPathContextPtr) intern->dom.ptr;
 	if (ctxp == NULL) {
-		php_error_docref(NULL, E_WARNING, "Invalid XPath Context");
-		RETURN_FALSE;
+		zend_throw_error(NULL, "Invalid XPath Context");
+		RETURN_THROWS();
 	}
 
 	docp = (xmlDocPtr) ctxp->doc;
@@ -384,8 +366,8 @@ static void php_xpath_eval(INTERNAL_FUNCTION_PARAMETERS, int type) /* {{{ */
 	}
 
 	if (nodep && docp != nodep->doc) {
-		php_error_docref(NULL, E_WARNING, "Node From Wrong Document");
-		RETURN_FALSE;
+		zend_throw_error(NULL, "Node from wrong document");
+		RETURN_THROWS();
 	}
 
 	ctxp->node = nodep;
@@ -414,6 +396,7 @@ static void php_xpath_eval(INTERNAL_FUNCTION_PARAMETERS, int type) /* {{{ */
 	}
 
 	if (! xpathobjp) {
+		/* TODO Add Warning? */
 		RETURN_FALSE;
 	}
 
@@ -461,7 +444,7 @@ static void php_xpath_eval(INTERNAL_FUNCTION_PARAMETERS, int type) /* {{{ */
 			} else {
 				ZVAL_EMPTY_ARRAY(&retval);
 			}
-			php_dom_create_interator(return_value, DOM_NODELIST);
+			php_dom_create_iterator(return_value, DOM_NODELIST);
 			nodeobj = Z_DOMOBJ_P(return_value);
 			dom_xpath_iter(&retval, nodeobj);
 			break;
@@ -488,49 +471,47 @@ static void php_xpath_eval(INTERNAL_FUNCTION_PARAMETERS, int type) /* {{{ */
 }
 /* }}} */
 
-/* {{{ proto DOMNodeList dom_xpath_query(string expr [,DOMNode context [, bool registerNodeNS]]) */
-PHP_FUNCTION(dom_xpath_query)
+/* {{{ */
+PHP_METHOD(DOMXPath, query)
 {
 	php_xpath_eval(INTERNAL_FUNCTION_PARAM_PASSTHRU, PHP_DOM_XPATH_QUERY);
 }
 /* }}} end dom_xpath_query */
 
-/* {{{ proto mixed dom_xpath_evaluate(string expr [,DOMNode context [, bool registerNodeNS]]) */
-PHP_FUNCTION(dom_xpath_evaluate)
+/* {{{ */
+PHP_METHOD(DOMXPath, evaluate)
 {
 	php_xpath_eval(INTERNAL_FUNCTION_PARAM_PASSTHRU, PHP_DOM_XPATH_EVALUATE);
 }
 /* }}} end dom_xpath_evaluate */
 
-/* {{{ proto void dom_xpath_register_php_functions() */
-PHP_FUNCTION(dom_xpath_register_php_functions)
+/* {{{ */
+PHP_METHOD(DOMXPath, registerPhpFunctions)
 {
-	zval *id;
-	dom_xpath_object *intern;
-	zval *array_value, *entry, new_string;
-	zend_string *name;
+	zval *id = ZEND_THIS;
+	dom_xpath_object *intern = Z_XPATHOBJ_P(id);
+	zval *entry, new_string;
+	zend_string *name = NULL;
+	HashTable *ht = NULL;
 
-	DOM_GET_THIS(id);
+	ZEND_PARSE_PARAMETERS_START(0, 1)
+		Z_PARAM_OPTIONAL
+		Z_PARAM_ARRAY_HT_OR_STR_OR_NULL(ht, name)
+	ZEND_PARSE_PARAMETERS_END();
 
-	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "a",  &array_value) == SUCCESS) {
-		intern = Z_XPATHOBJ_P(id);
-		ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(array_value), entry) {
+	if (ht) {
+		ZEND_HASH_FOREACH_VAL(ht, entry) {
 			zend_string *str = zval_get_string(entry);
-			ZVAL_LONG(&new_string,1);
+			ZVAL_LONG(&new_string, 1);
 			zend_hash_update(intern->registered_phpfunctions, str, &new_string);
 			zend_string_release_ex(str, 0);
 		} ZEND_HASH_FOREACH_END();
 		intern->registerPhpFunctions = 2;
-		RETURN_TRUE;
-
-	} else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "S",  &name) == SUCCESS) {
-		intern = Z_XPATHOBJ_P(id);
-
+	} else if (name) {
 		ZVAL_LONG(&new_string, 1);
 		zend_hash_update(intern->registered_phpfunctions, name, &new_string);
 		intern->registerPhpFunctions = 2;
 	} else {
-		intern = Z_XPATHOBJ_P(id);
 		intern->registerPhpFunctions = 1;
 	}
 
@@ -540,12 +521,3 @@ PHP_FUNCTION(dom_xpath_register_php_functions)
 #endif /* LIBXML_XPATH_ENABLED */
 
 #endif
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
